@@ -1,5 +1,6 @@
 import os
 from pathlib import Path
+import argparse
 
 class FolderGenie:
     def __init__(self, filename):
@@ -52,3 +53,17 @@ class FolderGenie:
         
     def generate_folders(self):
         self.create_directories(self.tree, os.getcwd())
+
+parser = argparse.ArgumentParser()
+parser.add_argument("source_file_path")
+args = parser.parse_args()
+
+source_file = Path(args.source_file_path)
+
+if not source_file.exists():
+    print('The source file does not exist')
+    raise SystemExit(1)
+
+# Generate the folders using the input file
+genie = FolderGenie(source_file)
+genie.generate_folders()
